<?php

declare(strict_types=1);

namespace Drupal\invoice_ninja\Plugin\ECA\Condition;

use Drupal\eca\Plugin\ECA\Condition\ConditionBase;
use Drupal\invoice_ninja\InvoiceNinjaSynchronizer;
use Drupal\invoice_ninja\SyncableInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * ECA condition plugin to get the sync status of an entity.
 *
 * @EcaCondition(
 *   id = "invoice_ninja_sync_status",
 *   label = @Translation("Sync status"),
 *   description = @Translation("Find out if a given entity has already been synced."),
 *   context_definitions = {
 *     "entity" = @ContextDefinition("entity", label = @Translation("Entity"))
 *   }
 * )
 */
class SyncStatus extends ConditionBase {

  /**
   * The Invoice Ninja synchronizer service.
   *
   * @var \Drupal\invoice_ninja\InvoiceNinjaSynchronizer
   */
  protected InvoiceNinjaSynchronizer $invoiceNinjaSynchronizer;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): static {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->invoiceNinjaSynchronizer = $container->get('invoice_ninja.synchronizer');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function evaluate(): bool {
    $entity = $this->getValueFromContext('entity');
    if ($entity instanceof SyncableInterface) {
      return $this->negationCheck($this->invoiceNinjaSynchronizer->isSynced($entity));
    }
    return $this->negationCheck(FALSE);
  }

}
